@@ -203,6 +203,7 @@ pub struct SourceConfig {
     pub transformers: Option<Vec<TransformerConfig>>,
     pub skip: Option<Vec<SkipConfig>>,
     pub database_subset: Option<DatabaseSubsetConfig>,
+    pub only_tables: Option<Vec<OnlyTablesConfig>>,
 }
 
 impl SourceConfig {
@@ -245,6 +246,12 @@ pub struct DatabaseSubsetConfig {
     pub passthrough_tables: Option<Vec<String>>,
 }
 
+#[derive(Debug, PartialEq, Serialize, Deserialize, Clone)]
+pub struct OnlyTablesConfig {
+    pub database: String,
+    pub table: String,
+}
+
 #[derive(Debug, PartialEq, Serialize, Deserialize, Clone)]
 #[serde(rename_all = "kebab-case")]
 #[serde(tag = "strategy_name", content = "strategy_options")]
