@@ -9,9 +9,9 @@ use log::info;
 
 use dump_parser::postgres::Keyword::NoKeyword;
 use dump_parser::postgres::{
-    get_column_names_from_insert_into_query, get_column_values_from_insert_into_query,
-    get_tokens_from_query_str, get_word_value_at_position, match_keyword_at_position, Keyword,
-    Token,
+    get_column_names_from_create_query, get_column_names_from_insert_into_query,
+    get_column_values_from_insert_into_query, get_tokens_from_query_str,
+    get_word_value_at_position, match_keyword_at_position, Keyword, Token,
 };
 use dump_parser::utils::{list_sql_queries_from_dump_reader, ListQueryResult};
 use subset::postgres::{PostgresSubset, SubsetStrategy};
@@ -19,10 +19,10 @@ use subset::{PassthroughTable, Subset, SubsetOptions};
 
 use crate::config::DatabaseSubsetConfigStrategy;
 use crate::connector::Connector;
-use crate::source::Source;
+use crate::source::{Explain, Source};
 use crate::transformer::Transformer;
 use crate::types::{Column, InsertIntoQuery, OriginalQuery, Query};
-use crate::utils::{binary_exists, wait_for_command};
+use crate::utils::{binary_exists, table, wait_for_command};
 use crate::DatabaseSubsetConfig;
 
 use super::SourceOptions;
@@ -75,6 +75,41 @@ impl<'a> Connector for Postgres<'a> {
     }
 }
 
+impl<'a> Explain for Postgres<'a> {
+    fn schema(&self) -> Result<(), Error> {
+        let s_port = self.port.to_string();
+
+        let dump_args = vec![
+            "-s", // dump only the schema definitions
+            "--no-owner",
+            "-h",
+            self.host,
+            "-p",
+            s_port.as_str(),
+            "-U",
+            self.username,
+        ];
+
+        let mut process = Command::new("pg_dump")
+            .env("PGPASSWORD", self.password)
+            .args(dump_args)
+            .stdout(Stdio::piped())
+            .stderr(Stdio::piped())
+            .spawn()?;
+
+        let stdout = process
+            .stdout
+            .take()
+            .ok_or_else(|| Error::new(ErrorKind::Other, "Could not capture standard output."))?;
+
+        let reader = BufReader::new(stdout);
+
+        read_and_parse_schema(reader)?;
+
+        wait_for_command(&mut process)
+    }
+}
+
 impl<'a> Source for Postgres<'a> {
     fn read<F: FnMut(OriginalQuery, Query)>(
         &self,
@@ -99,10 +134,7 @@ impl<'a> Source for Postgres<'a> {
             .iter()
             .map(|cfg| format!("--table={}.{}", cfg.database, cfg.table))
             .collect();
-        let mut only_tables_args: Vec<&str> = only_tables_args
-            .iter()
-            .map(String::as_str)
-            .collect();
+        let mut only_tables_args: Vec<&str> = only_tables_args.iter().map(String::as_str).collect();
 
         dump_args.append(&mut only_tables_args);
 
@@ -273,6 +305,39 @@ pub fn read_and_transform<R: Read, F: FnMut(OriginalQuery, Query)>(
     }
 }
 
+pub fn read_and_parse_schema<R: Read>(reader: BufReader<R>) -> Result<(), Error> {
+    match list_sql_queries_from_dump_reader(reader, |query| {
+        let tokens = get_tokens_from_query_str(query.clone());
+        match get_row_type(&tokens) {
+            RowType::CreateTable {
+                database_name,
+                table_name,
+            } => {
+                let column_schema = get_column_names_from_create_query(&tokens);
+
+                let mut table = table();
+                table.set_titles(row!["Field"]);
+
+                column_schema.iter().for_each(|column_name| {
+                    table.add_row(row![column_name]);
+                });
+
+                println!(" Table {}", table_name);
+
+                let _ = table.printstd();
+
+                println!();
+            }
+            _ => {}
+        }
+
+        ListQueryResult::Continue
+    }) {
+        Ok(_) => Ok(()),
+        Err(err) => panic!("{:?}", err),
+    }
+}
+
 fn no_change_query_callback<F: FnMut(OriginalQuery, Query)>(query_callback: &mut F, query: &str) {
     query_callback(
         // there is no diff between the original and the modified one
@@ -296,7 +361,13 @@ fn transform_columns(
     // R Paren      -> position X?
     let column_names = get_column_names_from_insert_into_query(&tokens);
     let column_values = get_column_values_from_insert_into_query(&tokens);
-    assert_eq!(column_names.len(), column_values.len(), "Column names do not match values: got {} names and {} values", column_names.len(), column_values.len());
+    assert_eq!(
+        column_names.len(),
+        column_values.len(),
+        "Column names do not match values: got {} names and {} values",
+        column_names.len(),
+        column_values.len()
+    );
 
     let mut original_columns = vec![];
     let mut columns = vec![];
